@@ -37,13 +37,11 @@ sub uscanResult {
             $data{$_} = $1;
         }
         else {
-            print STDERR
-              "Field $_ not found in uscan result, please investigate.\n\n"
-              . "DEHS output:\n$out\n\n"
-              . "Uscan stderr:\n$err\n\n";
+            print STDERR "Uscan failed\n";
+            return;
         }
     }
-    $data{'upstream-version'} =~ s/\+.*$//;
+    $data{'upstream-version'} =~ s/\+.*$// if $data{'upstream-version'};
     return ( $data{'upstream-version'}, $data{'upstream-url'} );
 }
 
@@ -92,7 +90,7 @@ sub git_watch {
     my ( $repo, $component, $type, $version, $after, $noctype ) = @_;
     $version   = $version   ? "v?($version(?:\.[\\d\\.]+)?)" : "v?([\\d\\.]+)";
     $component = $component ? "component=$component,\\\n"    : '',
-      $type    = $type      ? " $type"                       : '';
+      $type = $type ? " $type" : '';
     $component .= "ctype=nodejs,\\\n" unless ($noctype);
     my $name = $repo;
     $name =~ s#.*/([^/]+)/?#$1#;
@@ -102,7 +100,7 @@ sub git_watch {
         return <<"EOF";
 opts=\\
 ${component}dversionmangle=auto,\\
-filenamemangle=s/.*\\/v?([\\d\\.-]+)\\.tar\\.gz/node-$name-\$1.tar.gz/ \\
+filenamemangle=s/.*?(\\d[\\d\\.-]*\@ARCHIVE_EXT\@)/node-$name-\$1/ \\
  $repo/tags$after .*/archive.*/$version.tar.gz$type
 EOF
     }
@@ -113,6 +111,7 @@ EOF
 
 sub registry_watch {
     my ( $pname, $component, $type, $version, $noctype ) = @_;
+    my $localName = $component ? "node-$component" : '@PACKAGE@';
     $version   = $version   ? "($version(?:\.[\\d\\.]+)?)" : "([\\d\\.]+)";
     $component = $component ? ",component=$component"      : '';
     $type      = $type      ? " $type"                     : '';
@@ -122,7 +121,7 @@ sub registry_watch {
     return <<"EOF";
 # It is not recommended use npmregistry. Please investigate more.
 # Take a look at https://wiki.debian.org/debian/watch/
-opts="searchmode=plain$component,pgpmode=none" \\
+opts="searchmode=plain$component,pgpmode=none,filenamemangle=s/^.*?(\\d[\\d\\.-]*\@ARCHIVE_EXT\@)/$localName-\$1/" \\
  https://registry.npmjs.org/$pname https://registry.npmjs.org/$pname/-/$fname-$version\@ARCHIVE_EXT\@$type
 EOF
 }
